==> vscat-1.0.0.tgz: package/tests/highlighting/sources/json/npm-package/results/output.abyss.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test abyss theme 1`] = `
Object {
  "lines": Array [
    "[48;2;0;12;24m [38;2;64;99;133m 1 │ [39m[38;2;102;136;204m{[39m                                                                         [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 2 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"name\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"test-package\\"[39m[38;2;102;136;204m,[39m                                                 [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 3 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"description\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"Some[39m[38;2;16;48;80m·[39m[38;2;34;170;68museful[39m[38;2;16;48;80m·[39m[38;2;34;170;68mpackage[39m[38;2;16;48;80m·[39m[38;2;34;170;68mto[39m[38;2;16;48;80m·[39m[38;2;34;170;68mdo[39m[38;2;16;48;80m·[39m[38;2;34;170;68msome[39m[38;2;16;48;80m·[39m[38;2;34;170;68museful[39m[38;2;16;48;80m·[39m[38;2;34;170;68mstuff[39m[38;2;16;48;80m·[39m[38;2;34;170;68mwith[39m[38;2;16;48;80m·[39m[38;2;34;170;68madvanc[39m[38;2;34;170;68m…[39m[49m",
    "[48;2;0;12;24m [38;2;64;99;133m 4 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"version\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"1.0.0\\"[39m[38;2;102;136;204m,[39m                                                     [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 5 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"private\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;242;128;208mtrue[39m[38;2;102;136;204m,[39m                                                        [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 6 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"license\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"MIT\\"[39m[38;2;102;136;204m,[39m                                                       [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 7 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"dependencies\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;102;136;204m{[39m                                                       [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 8 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"package-1\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"1.0.0\\"[39m[38;2;102;136;204m,[39m                                                 [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 9 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"package-2\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"2.0.0\\"[39m[38;2;102;136;204m,[39m                                                 [49m",
    "[48;2;0;12;24m [38;2;64;99;133m10 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"package-3\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"3.0.0\\"[39m[38;2;102;136;204m,[39m                                                 [49m",
    "[48;2;0;12;24m [38;2;64;99;133m11 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"package-4\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"4.0.0\\"[39m[38;2;102;136;204m,[39m                                                 [49m",
    "[48;2;0;12;24m [38;2;64;99;133m12 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"package-5\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"5.0.0\\"[39m[38;2;102;136;204m,[39m                                                 [49m",
    "[48;2;0;12;24m [38;2;64;99;133m13 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"package-6\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;0;12;24m [38;2;64;99;133m14 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;102;136;204m}[39m                                                                       [49m",
    "[48;2;0;12;24m [38;2;64;99;133m15 │ [39m[38;2;102;136;204m}[39m                                                                         [49m",
    "[48;2;0;12;24m [38;2;64;99;133m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #6688CC │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #6688CC │   
 1 │  2, 8 │ #9966B8 │ \\"name\\"
 1 │  8,10 │ #6688CC │ : 
 1 │ 10,24 │ #22AA44 │ \\"test-package\\"
 1 │ 24,25 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 2 │ #6688CC │   
 2 │  2,15 │ #9966B8 │ \\"description\\"
 2 │ 15,17 │ #6688CC │ : 
 2 │ 17,90 │ #22AA44 │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 2 │ #6688CC │   
 3 │  2,11 │ #9966B8 │ \\"version\\"
 3 │ 11,13 │ #6688CC │ : 
 3 │ 13,20 │ #22AA44 │ \\"1.0.0\\"
 3 │ 20,21 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 2 │ #6688CC │   
 4 │  2,11 │ #9966B8 │ \\"private\\"
 4 │ 11,13 │ #6688CC │ : 
 4 │ 13,17 │ #F280D0 │ true
 4 │ 17,18 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #6688CC │   
 5 │  2,11 │ #9966B8 │ \\"license\\"
 5 │ 11,13 │ #6688CC │ : 
 5 │ 13,18 │ #22AA44 │ \\"MIT\\"
 5 │ 18,19 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #6688CC │   
 6 │  2,16 │ #9966B8 │ \\"dependencies\\"
 6 │ 16,19 │ #6688CC │ : {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0, 4 │ #6688CC │     
 7 │  4,15 │ #9966B8 │ \\"package-1\\"
 7 │ 15,17 │ #6688CC │ : 
 7 │ 17,24 │ #22AA44 │ \\"1.0.0\\"
 7 │ 24,25 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 4 │ #6688CC │     
 8 │  4,15 │ #9966B8 │ \\"package-2\\"
 8 │ 15,17 │ #6688CC │ : 
 8 │ 17,24 │ #22AA44 │ \\"2.0.0\\"
 8 │ 24,25 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 4 │ #6688CC │     
 9 │  4,15 │ #9966B8 │ \\"package-3\\"
 9 │ 15,17 │ #6688CC │ : 
 9 │ 17,24 │ #22AA44 │ \\"3.0.0\\"
 9 │ 24,25 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  0, 4 │ #6688CC │     
10 │  4,15 │ #9966B8 │ \\"package-4\\"
10 │ 15,17 │ #6688CC │ : 
10 │ 17,24 │ #22AA44 │ \\"4.0.0\\"
10 │ 24,25 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  0, 4 │ #6688CC │     
11 │  4,15 │ #9966B8 │ \\"package-5\\"
11 │ 15,17 │ #6688CC │ : 
11 │ 17,24 │ #22AA44 │ \\"5.0.0\\"
11 │ 24,25 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  0, 4 │ #6688CC │     
12 │  4,15 │ #9966B8 │ \\"package-6\\"
12 │ 15,17 │ #6688CC │ : 
12 │ 17,24 │ #22AA44 │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  0, 3 │ #6688CC │   }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ #6688CC │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;

==> vscat-1.0.1.tgz: package/tests/highlighting/sources/json/npm-package/results/output.abyss.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test abyss theme 1`] = `
Object {
  "lines": Array [
    "[48;2;0;12;24m [38;2;64;99;133m 1 │ [39m[38;2;102;136;204m{[39m                                                                         [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 2 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"name\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"test-package\\"[39m[38;2;102;136;204m,[39m                                                 [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 3 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"description\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"Some[39m[38;2;16;48;80m·[39m[38;2;34;170;68museful[39m[38;2;16;48;80m·[39m[38;2;34;170;68mpackage[39m[38;2;16;48;80m·[39m[38;2;34;170;68mto[39m[38;2;16;48;80m·[39m[38;2;34;170;68mdo[39m[38;2;16;48;80m·[39m[38;2;34;170;68msome[39m[38;2;16;48;80m·[39m[38;2;34;170;68museful[39m[38;2;16;48;80m·[39m[38;2;34;170;68mstuff[39m[38;2;16;48;80m·[39m[38;2;34;170;68mwith[39m[38;2;16;48;80m·[39m[38;2;34;170;68madvanc…[39m[49m",
    "[48;2;0;12;24m [38;2;64;99;133m 4 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"version\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"1.0.0\\"[39m[38;2;102;136;204m,[39m                                                     [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 5 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"private\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;242;128;208mtrue[39m[38;2;102;136;204m,[39m                                                        [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 6 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"license\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"MIT\\"[39m[38;2;102;136;204m,[39m                                                       [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 7 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"dependencies\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;102;136;204m{[39m                                                       [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 8 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"package-1\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"1.0.0\\"[39m[38;2;102;136;204m,[39m                                                 [49m",
    "[48;2;0;12;24m [38;2;64;99;133m 9 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"package-2\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"2.0.0\\"[39m[38;2;102;136;204m,[39m                                                 [49m",
    "[48;2;0;12;24m [38;2;64;99;133m10 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"package-3\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"3.0.0\\"[39m[38;2;102;136;204m,[39m                                                 [49m",
    "[48;2;0;12;24m [38;2;64;99;133m11 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"package-4\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"4.0.0\\"[39m[38;2;102;136;204m,[39m                                                 [49m",
    "[48;2;0;12;24m [38;2;64;99;133m12 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"package-5\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"5.0.0\\"[39m[38;2;102;136;204m,[39m                                                 [49m",
    "[48;2;0;12;24m [38;2;64;99;133m13 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;153;102;184m\\"package-6\\"[39m[38;2;102;136;204m:[39m[38;2;16;48;80m·[39m[38;2;34;170;68m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;0;12;24m [38;2;64;99;133m14 │ [39m[38;2;16;48;80m·[39m[38;2;16;48;80m·[39m[38;2;102;136;204m}[39m                                                                       [49m",
    "[48;2;0;12;24m [38;2;64;99;133m15 │ [39m[38;2;102;136;204m}[39m                                                                         [49m",
    "[48;2;0;12;24m [38;2;64;99;133m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #6688CC │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #6688CC │   
 1 │  2, 8 │ #9966B8 │ \\"name\\"
 1 │  8,10 │ #6688CC │ : 
 1 │ 10,24 │ #22AA44 │ \\"test-package\\"
 1 │ 24,25 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 2 │ #6688CC │   
 2 │  2,15 │ #9966B8 │ \\"description\\"
 2 │ 15,17 │ #6688CC │ : 
 2 │ 17,90 │ #22AA44 │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 2 │ #6688CC │   
 3 │  2,11 │ #9966B8 │ \\"version\\"
 3 │ 11,13 │ #6688CC │ : 
 3 │ 13,20 │ #22AA44 │ \\"1.0.0\\"
 3 │ 20,21 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 2 │ #6688CC │   
 4 │  2,11 │ #9966B8 │ \\"private\\"
 4 │ 11,13 │ #6688CC │ : 
 4 │ 13,17 │ #F280D0 │ true
 4 │ 17,18 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #6688CC │   
 5 │  2,11 │ #9966B8 │ \\"license\\"
 5 │ 11,13 │ #6688CC │ : 
 5 │ 13,18 │ #22AA44 │ \\"MIT\\"
 5 │ 18,19 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #6688CC │   
 6 │  2,16 │ #9966B8 │ \\"dependencies\\"
 6 │ 16,19 │ #6688CC │ : {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0, 4 │ #6688CC │     
 7 │  4,15 │ #9966B8 │ \\"package-1\\"
 7 │ 15,17 │ #6688CC │ : 
 7 │ 17,24 │ #22AA44 │ \\"1.0.0\\"
 7 │ 24,25 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 4 │ #6688CC │     
 8 │  4,15 │ #9966B8 │ \\"package-2\\"
 8 │ 15,17 │ #6688CC │ : 
 8 │ 17,24 │ #22AA44 │ \\"2.0.0\\"
 8 │ 24,25 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 4 │ #6688CC │     
 9 │  4,15 │ #9966B8 │ \\"package-3\\"
 9 │ 15,17 │ #6688CC │ : 
 9 │ 17,24 │ #22AA44 │ \\"3.0.0\\"
 9 │ 24,25 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  0, 4 │ #6688CC │     
10 │  4,15 │ #9966B8 │ \\"package-4\\"
10 │ 15,17 │ #6688CC │ : 
10 │ 17,24 │ #22AA44 │ \\"4.0.0\\"
10 │ 24,25 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  0, 4 │ #6688CC │     
11 │  4,15 │ #9966B8 │ \\"package-5\\"
11 │ 15,17 │ #6688CC │ : 
11 │ 17,24 │ #22AA44 │ \\"5.0.0\\"
11 │ 24,25 │ #6688CC │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  0, 4 │ #6688CC │     
12 │  4,15 │ #9966B8 │ \\"package-6\\"
12 │ 15,17 │ #6688CC │ : 
12 │ 17,24 │ #22AA44 │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  0, 3 │ #6688CC │   }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ #6688CC │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;
